==> gkrellm-0.9.10.tgz: include/gkrellm/gkrellm_private_proto.h <==
/* GKrellM
|  Copyright (C) 1999-2000 Bill Wilson
|
|  Author:  Bill Wilson    bill@gkrellm.net
|  Latest versions might be found at:  http://gkrellm.net
|
|  This program is free software which I release under the GNU General Public
|  License. You may redistribute and/or modify this program under the terms
|  of that license as published by the Free Software Foundation; either
|  version 2 of the License, or (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
| 
|  To get a copy of the GNU General Puplic License, write to the Free Software
|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Private global extern declarations and function prototypes.
*/
extern GtkWidget	*top_window;

extern struct tm	current_tm;
extern time_t		time_now;

extern gchar		*exec_theme_path;

extern gint			smp_cpus;
extern gint			w_display, h_display;
extern gint			n_system_plugins;

extern GdkImlibBorder zero_border;

void load_plugin_monitors(void);

void	create_plugin_config(GtkWidget *);
void	save_plugins_enable_list(void);

/* hostname?? */
Monitor *init_clock_monitor(void);
Monitor *init_cpu_monitor(void);
Monitor *init_proc_monitor(void);
Monitor *init_inet_monitor(void);
Monitor *init_disk_monitor(void);
Monitor *init_net_monitor(void);
Monitor *init_meminfo_monitor(void);
Monitor *init_fs_monitor(void);
Monitor *init_mail_monitor(void);
Monitor *init_apm_monitor(void);
Monitor *init_uptime_monitor(void);
Monitor *init_sensors_monitor(void);

Monitor *init_demo_monitor(void);

void	destroy_decal_button_list(void);

void	apply_hostname_config(void);
void	create_hostname(GtkWidget *, gint);
void	insert_spacer(GtkWidget *);

void	store_proc_chart_data(Chart *, gint, gint);
void	draw_proc_chart(Chart *);

void	build_gkrellm(void);
void	gkrellmrc_theme_config();
int		read_user_config(void);
void	save_user_config(void);

gint	x_label_position(gint, gint, gint, gint);

void	load_inet_data(void);
void	save_inet_data(void);

void	load_theme_images(void);

gint	render_to_pixmap(GdkImlibImage *, GdkPixmap **, GdkBitmap **, gint, gint);

gint	effect_string_value(gchar *);

void	set_on_top(gint);

void	map_color_string(gchar *, GdkColor *);

void	add_plugin_config_page(Monitor *);
void	remove_plugin_config_page(Monitor *);
GtkWidget *create_tab(GtkWidget *, gchar *);

void	make_check_button(GtkWidget *, GtkWidget **, gint, gint, gchar *);
void	make_check_button_shrink(GtkWidget *, GtkWidget **, gint, gint, gchar *);
void	insert_expanded_filler(GtkWidget *);

gchar	*entry_get_alpha_text(GtkWidget **);

void	set_theme_alternatives_label();

gchar	*homedir(void);
gint	isdir(gchar *);
gint	isfile(gchar *);
void	dup_string(gchar **, gchar *);

void	start_timer(gint);

GtkItemFactory *create_item_factory_popup(void);

gint	read_temperature(gchar *, gchar *, gint);
int		map_1_2_5(gint, gint *, gint);
gint	computed_index(Chart *, gint);

==> gkrellm-0.10.5.tgz: include/gkrellm/gkrellm_private_proto.h <==
/* GKrellM
|  Copyright (C) 1999-2000 Bill Wilson
|
|  Author:  Bill Wilson    bill@gkrellm.net
|  Latest versions might be found at:  http://gkrellm.net
|
|  This program is free software which I release under the GNU General Public
|  License. You may redistribute and/or modify this program under the terms
|  of that license as published by the Free Software Foundation; either
|  version 2 of the License, or (at your option) any later version.
|
|  This program is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
|  GNU General Public License for more details.
| 
|  To get a copy of the GNU General Puplic License, write to the Free Software
|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/* Private global extern declarations and function prototypes.
*/
extern GtkWidget	*top_window;

extern struct tm	current_tm;
extern time_t		time_now;

extern gchar		*exec_theme_path;

extern gint			smp_cpus;
extern gint			w_display, h_display;
extern gint			window_decorations;
extern gint			n_system_plugins;

extern GdkImlibBorder zero_border;

void load_plugin_monitors(void);

void	create_plugin_config(GtkWidget *);
void	save_plugins_enable_list(void);

/* hostname?? */
Monitor *init_host_monitor(void);
Monitor *init_cal_monitor(void);
Monitor *init_clock_monitor(void);
Monitor *init_cpu_monitor(void);
Monitor *init_proc_monitor(void);
Monitor *init_inet_monitor(void);
Monitor *init_disk_monitor(void);
Monitor *init_net_monitor(void);
Monitor *init_timer_monitor(void);
Monitor *init_mem_monitor(void);
Monitor *init_swap_monitor(void);
Monitor *init_fs_monitor(void);
Monitor *init_mail_monitor(void);
Monitor *init_apm_monitor(void);
Monitor *init_uptime_monitor(void);
Monitor *init_sensors_monitor(void);

Monitor *init_demo_monitor(void);

void	init_hostname_monitor(void);	/* XXX */

void	read_stat_swap(gulong *, gulong *);

void	destroy_decal_button_list(void);
void	free_glist_and_data(GList **);

void	create_hostname(GtkWidget *, gint);
void	insert_spacer(GtkWidget *);

void	store_proc_chart_data(Chart *, gint, gint);
void	draw_proc_chart(Chart *);

void	build_gkrellm(void);
void	gkrellmrc_theme_config();
int		read_user_config(void);
void	save_user_config(void);

gint	x_label_position(gint, gint, gint, gint);

void	load_inet_data(void);
void	save_inet_data(void);

void	load_theme_images(void);

gint	render_to_pixmap(GdkImlibImage *, GdkPixmap **, GdkBitmap **, gint, gint);

gint	effect_string_value(gchar *);

void	set_on_top(gint);

void	map_color_string(gchar *, GdkColor *);

void	add_plugin_config_page(Monitor *);
void	remove_plugin_config_page(Monitor *);
GtkWidget *create_tab(GtkWidget *, gchar *);

void	make_int_spin_button(GtkWidget *, GtkWidget **, gint, gint,
			gint, gint, gint, gint, void (*func)(), gpointer, gchar *);

void	make_check_button(GtkWidget *, GtkWidget **, gint, gint, gchar *);
void	make_check_button_shrink(GtkWidget *, GtkWidget **, gint, gint, gchar *);
void	insert_expanded_filler(GtkWidget *);

gchar	*entry_get_alpha_text(GtkWidget **);

void	set_theme_alternatives_label();

gchar	*homedir(void);
gint	isdir(gchar *);
gint	isfile(gchar *);
void	dup_string(gchar **, gchar *);
gchar	*cut_quoted_string(gchar *, gchar **);

void	start_timer(gint);

GtkItemFactory *create_item_factory_popup(void);

gint	read_temperature(gchar *, gchar *, gint);
int		map_1_2_5(gint, gint *, gint);
gint	computed_index(Chart *, gint);
